@@ -97,7 +97,7 @@ BREAK_TE(){
 	unlink $FILELIST
 }
 
-cd /root/segatex/raw_te_files
+cd /usr/share/segatex/raw_te_files
 
 ### Get directory name under current directory and put into var.
 DICNAME=`find ./ -type d -name "*" | awk -F/ '{ print $2 }'`
