@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2009 Shintaro Fujiwara 
+ * Copyright (C) 2007-2010 Shintaro Fujiwara 
  * shintaro.fujiwara@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,8 +22,14 @@
 
 #include "downloader.h"
 
+#include <iostream>
+using namespace std;
+
+
 Downloader::Downloader(const QUrl &url, QString version)
 {
+//	cout << "downloader is called " << endl;
+
     //if (url.protocol() != "ftp") {
     if (url.scheme() != "ftp") {
         QMessageBox::warning(0, tr("Downloader"),
@@ -50,31 +56,45 @@ Downloader::Downloader(const QUrl &url, QString version)
 		/*
 		if(version == "seven")
 			ftp.cd("Linux/fedora/releases/7/Fedora/i386/iso");
-		*/
 		if(version == "eight")
 			ftp.cd("Linux/fedora/releases/8/Fedora/i386/iso");
+		*/
 		if(version == "nine")
 			ftp.cd("Linux/fedora/releases/9/Fedora/i386/iso");
 		if(version == "ten")
 			ftp.cd("Linux/fedora/releases/10/Fedora/i386/iso");
+		if(version == "eleven"){
+			ftp.cd("Linux/fedora/releases/11/Fedora/i386/iso");
+			cout << "cd to F11 " << endl;
+		}
+		if(version == "twelve"){
+			ftp.cd("Linux/fedora/releases/12/Fedora/i386/iso");
+			cout << "cd to F12 " << endl;
+		}
 	}
 	if(url.host() == "mirrors.usc.edu"){
 		/*
 		if(version == "seven")
 			ftp.cd("pub/linux/distributions/fedora/linux/releases/7/Fedora/i386/iso");
-		*/
 		if(version == "eight")
 			ftp.cd("pub/linux/distributions/fedora/linux/releases/8/Fedora/i386/iso");
+		*/
 		if(version == "nine")
 			ftp.cd("pub/linux/distributions/fedora/linux/releases/9/Fedora/i386/iso");
 		if(version == "ten")
 			ftp.cd("pub/linux/distributions/fedora/linux/releases/10/Fedora/i386/iso");
+		if(version == "eleven")
+			ftp.cd("pub/linux/distributions/fedora/linux/releases/11/Fedora/i386/iso");
+		if(version == "twelve")
+			ftp.cd("pub/linux/distributions/fedora/linux/releases/12/Fedora/i386/iso");
 	}
 	ftp.list();
 }
 
 void Downloader::listInfo(const QUrlInfo &urlInfo)
 {
+	cout << "downloading files" << endl;
+
     if (urlInfo.isFile() && urlInfo.isReadable()) {
         QFile *file = new QFile(urlInfo.name());
         if (!file->open(QIODevice::WriteOnly)) {
