@@ -31,7 +31,7 @@ class SegatexAlertAudit: public QDialog
 {
 	Q_OBJECT
 public:
-	SegatexAlertAudit(QWidget *parent = 0, const char *name = 0);
+	SegatexAlertAudit(QWidget *parent = 0);
 public slots:
 signals:
 protected:
