@@ -27,9 +27,11 @@
 //using namespace std;
 
 //default constructor
-TEST::TEST(QWidget *parent, const char *name): QDialog(parent, name)
+//TEST::TEST(QWidget *parent, const char *name): QDialog(parent, name)
+TEST::TEST(QWidget *parent): QDialog(parent, Qt::WindowFlags())
 {
-                setCaption(tr("segatex alert audit"));
+                //setCaption(tr("segatex alert audit"));
+                setWindowTitle(tr("segatex alert audit"));
                 alertLabel = new QLabel(tr("Denied message in audit.log !"), this );
                 mainLayout = new QHBoxLayout(this);
                 mainLayout->setMargin(11);
