@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2009 Shintaro Fujiwara 
+ * Copyright (C) 2007-2010 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,16 +58,18 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 	/*
         sevenRadioButton = new QRadioButton(tr("version 7"), fedoraVersionButtonGroup);
         sevenRadioButton->setGeometry( 10, 10, 300, 20 );
-	*/
         eightRadioButton = new QRadioButton(tr("version 8"), fedoraVersionButtonGroup);
         eightRadioButton->setGeometry( 10, 10, 300, 20 );
+	*/
         nineRadioButton = new QRadioButton(tr("version 9"), fedoraVersionButtonGroup);
-        nineRadioButton->setGeometry( 10, 30, 300, 20 );
+        nineRadioButton->setGeometry( 10, 10, 300, 20 );
         tenRadioButton = new QRadioButton(tr("version 10"), fedoraVersionButtonGroup);
-        tenRadioButton->setGeometry( 10, 50, 300, 20 );
+        tenRadioButton->setGeometry( 10, 30, 300, 20 );
         elevenRadioButton = new QRadioButton(tr("version 11"), fedoraVersionButtonGroup);
-        elevenRadioButton->setGeometry( 10, 70, 300, 20 );
-	elevenRadioButton->setChecked(true);
+        elevenRadioButton->setGeometry( 10, 50, 300, 20 );
+        twelveRadioButton = new QRadioButton(tr("version 12"), fedoraVersionButtonGroup);
+        twelveRadioButton->setGeometry( 10, 70, 300, 20 );
+	twelveRadioButton->setChecked(true);
 
 	downloadButton = new QPushButton(tr("Download Fedora"), this);
 	downloadButton->setPaletteBackgroundColor(QColor(100,200,200));
@@ -126,10 +128,10 @@ void Downloader::download_button_clicked()
 		if(sevenRadioButton->isChecked()){
 			version = "seven";
 		}
-		*/
 		if(eightRadioButton->isChecked()){
 			version = "eight";
 		}
+		*/
 		if(nineRadioButton->isChecked()){
 			version = "nine";
 		}
@@ -139,6 +141,9 @@ void Downloader::download_button_clicked()
 		if(elevenRadioButton->isChecked()){
 			version = "eleven";
 		}
+		if(twelveRadioButton->isChecked()){
+			version = "twelve";
+		}
 	}
 	if(jpRadioButton->isChecked()){
 		Q3Url url_for_fedora("ftp://ftp.riken.jp");
@@ -148,10 +153,10 @@ void Downloader::download_button_clicked()
 		if(sevenRadioButton->isChecked()){
 			version = "seven";
 		}
-		*/
 		if(eightRadioButton->isChecked()){
 			version = "eight";
 		}
+		*/
 		if(nineRadioButton->isChecked()){
 			version = "nine";
 		}
@@ -161,6 +166,9 @@ void Downloader::download_button_clicked()
 		if(elevenRadioButton->isChecked()){
 			version = "eleven";
 		}
+		if(twelveRadioButton->isChecked()){
+			version = "twelve";
+		}
 	}
 	downloader_process(url_for_fedora,version);
 }
