@@ -1,7 +1,7 @@
 /********************************************
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2009 Shintaro Fujiwara 
+ * Copyright (C) 2007-2010 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -92,6 +92,7 @@
 #include "semanage_core_boolean_process.h"
 #include "semanage_core_permissive_process.h"
 #include "seinfo.h"
+#include "sesearch.h"
 #include "autorelabel.h"
 #include "policygeneration.h"
 #include "aureport.h"
@@ -104,6 +105,13 @@
 #include "sqlrefpolicy.h"
 #include "semodule_dontaudit.h"
 #include "segatex_getseuserbyname.h"
+#include "segatex_getorderedcontextlist.h"
+#include "segatex_classaccessvector.h"
+#include "segatex_booleannames.h"
+#include "segatex_getpidcon.h"
+#include "segatex_selinuxpath.h"
+//#include <iostream>
+//using namespace std;
 
  MainWindow::MainWindow()
 {
@@ -142,6 +150,7 @@
 	semanage_core_boolean_process_o = 0;
 	semanage_core_permissive_process_o = 0;
 	seinfo_o = 0;
+	sesearch_o = 0;
 	autorelabel_process_o = 0;
 	policygeneration_process_o = 0;
 	aureport_o = 0;
@@ -153,9 +162,11 @@
 	sqlrefpolicy_o = 0;
 	semodule_dontaudit_o = 0;
 	segatex_getseuserbyname_o = 0;
-
-	//semodule_dontaudit_o = new SemoduleDontaudit(this);
-	//semodule_dontaudit_o->semodule_dontaudit_base_process();
+	segatex_getorderedcontextlist_o = 0;
+	segatex_classaccessvector_o = 0;
+	segatex_booleannames_o = 0;
+	segatex_getpidcon_o = 0;
+	segatex_selinuxpath_o = 0;
 
 	createActions();
 	createMenus();
@@ -163,11 +174,9 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	setWindowTitle(tr("segatex-7.780"));
+	setWindowTitle(tr("segatex-7.791"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
-	//for test
-	//audit2allow();
 }
 void MainWindow::createMenus()
 {
@@ -176,6 +185,7 @@ void MainWindow::createMenus()
 	fileMenu->addAction(openAct);
 	fileMenu->addAction(saveAct);
 	fileMenu->addAction(saveAsAct);
+	fileMenu->addAction(removeAct);
 	fileMenu->addSeparator();
 	QAction *action = fileMenu->addAction(tr("Switch layout direction"));
 	connect(action, SIGNAL(triggered()), this, SLOT(switchLayoutDirection()));
@@ -204,8 +214,12 @@ void MainWindow::createMenus()
 	policyMenu->addAction(enforcingAct);
 	policyMenu->addAction(check_selinuxAct);
 	policyMenu->addAction(default_policyAct);
-	policyMenu->addAction(selinux_pathAct);
+	policyMenu->addAction(segatex_selinuxpathAct);
 	policyMenu->addAction(segatex_getseuserbynameAct);
+	policyMenu->addAction(segatex_getorderedcontextlistAct);
+	policyMenu->addAction(segatex_classaccessvectorAct);
+	policyMenu->addAction(segatex_booleannamesAct);
+	policyMenu->addAction(segatex_getpidconAct);
 
 	manageMenu = menuBar()->addMenu(tr("&Modules"));
 	manageMenu->addAction(semodule_core_processAct);
@@ -220,6 +234,7 @@ void MainWindow::createMenus()
 	semanageMenu->addAction(semanage_core_boolean_processAct);
 	semanageMenu->addAction(semanage_core_permissive_processAct);
 	semanageMenu->addAction(seinfoAct);
+	semanageMenu->addAction(sesearchAct);
 
 	relabelMenu = menuBar()->addMenu(tr("Re&label"));
 	relabelMenu->addAction(restoreconAct);
@@ -269,6 +284,12 @@ void MainWindow::createActions()
 	connect(saveAsAct, SIGNAL(triggered()), this, SLOT(saveAs()));
 	connect(newAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	removeAct = new QAction(QIcon(":/images/remove.png"), tr("&Remove"), this);
+	removeAct->setShortcut(tr("Ctrl+S"));
+	removeAct->setStatusTip(tr("Remove the document from disk"));
+	connect(removeAct, SIGNAL(triggered()), this, SLOT(remove()));
+	connect(newAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
 	exitAct = new QAction(tr("E&xit"), this);
 	exitAct->setShortcut(tr("Ctrl+Q"));
 	exitAct->setStatusTip(tr("Exit the application"));
@@ -360,15 +381,35 @@ void MainWindow::createActions()
 	connect(enforcingAct, SIGNAL(activated()), this, SLOT(enforcing()));
 	connect(enforcingAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	selinux_pathAct = new QAction(tr("Check SELinux &path"), this);
-	selinux_pathAct->setStatusTip(tr("Check SELinux path"));
-	connect(selinux_pathAct, SIGNAL(activated()), segatex_state, SLOT(segatex_selinux_path()));
-	connect(selinux_pathAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+	segatex_selinuxpathAct = new QAction(tr("Check SELinux &path"), this);
+	segatex_selinuxpathAct->setStatusTip(tr("Check SELinux path"));
+	connect(segatex_selinuxpathAct, SIGNAL(activated()), this, SLOT(segatex_selinuxpath()));
+	connect(segatex_selinuxpathAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
 	segatex_getseuserbynameAct = new QAction(tr("Get se&user and level from linuxuser"), this);
 	segatex_getseuserbynameAct->setStatusTip(tr("Get seuser and level from linuxuser"));
 	connect(segatex_getseuserbynameAct, SIGNAL(activated()), this, SLOT(segatex_getseuserbyname()));
 	connect(segatex_getseuserbynameAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	segatex_getorderedcontextlistAct = new QAction(tr("Get an &ordered list of authorized security contexts for a user session for seuser"), this);
+	segatex_getorderedcontextlistAct->setStatusTip(tr("Get an ordered list of authorized security contexts for a user session for seuser"));
+	connect(segatex_getorderedcontextlistAct, SIGNAL(activated()), this, SLOT(segatex_getorderedcontextlist()));
+	connect(segatex_getorderedcontextlistAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	segatex_classaccessvectorAct = new QAction(tr("Get a full list of class and access &vector"), this);
+	segatex_classaccessvectorAct->setStatusTip(tr("Get a full list of class and access vector"));
+	connect(segatex_classaccessvectorAct, SIGNAL(activated()), this, SLOT(segatex_classaccessvector()));
+	connect(segatex_classaccessvectorAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	segatex_booleannamesAct = new QAction(tr("Get a full list of &boolean names and its values"), this);
+	segatex_booleannamesAct->setStatusTip(tr("Get a full list of boolean names and its values"));
+	connect(segatex_booleannamesAct, SIGNAL(activated()), this, SLOT(segatex_booleannames()));
+	connect(segatex_booleannamesAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	segatex_getpidconAct = new QAction(tr("Get security context from &process id"), this);
+	segatex_getpidconAct->setStatusTip(tr("Get security context from process id"));
+	connect(segatex_getpidconAct, SIGNAL(activated()), this, SLOT(segatex_getpidcon()));
+	connect(segatex_getpidconAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 /////////////////////// Audit ////////////////////////////////////////
 	semodule_dontauditAct = new QAction(tr("dont&audit"), this);
 	semodule_dontauditAct->setStatusTip(tr("manage dontaudit"));
@@ -444,6 +485,11 @@ void MainWindow::createActions()
 	seinfoAct->setStatusTip(tr("Seinfo [options]"));
 	connect(seinfoAct, SIGNAL(activated()), this, SLOT(seinfo()));
 	connect(seinfoAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	sesearchAct = new QAction(tr("se&search"), this);
+	sesearchAct->setStatusTip(tr("Sesearch [options]"));
+	connect(sesearchAct, SIGNAL(activated()), this, SLOT(sesearch()));
+	connect(sesearchAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 /////////////////////// Relabel ////////////////////////////////////////////////
 	restoreconAct = new QAction(tr("&restorecon"), this);
 	restoreconAct->setStatusTip(tr("restorecon"));
@@ -545,36 +591,42 @@ void MainWindow::open()
 		}
 	}
 }
- void MainWindow::save()
- {
-     if (activeMdiChild() && activeMdiChild()->save())
-         statusBar()->showMessage(tr("File saved"), 2000);
- }
- void MainWindow::saveAs()
- {
-     if (activeMdiChild() && activeMdiChild()->saveAs())
-         statusBar()->showMessage(tr("File saved"), 2000);
- }
- void MainWindow::cut()
- {
-     if (activeMdiChild())
-         activeMdiChild()->cut();
- }
- void MainWindow::copy()
- {
-     if (activeMdiChild())
-         activeMdiChild()->copy();
- }
- void MainWindow::paste()
- {
-     if (activeMdiChild())
-         activeMdiChild()->paste();
- }
+void MainWindow::save()
+{
+	if (activeMdiChild() && activeMdiChild()->save())
+	statusBar()->showMessage(tr("File saved"), 2000);
+}
+void MainWindow::remove()
+{
+	if (activeMdiChild() && activeMdiChild()->remove())
+	statusBar()->showMessage(tr("File removed"), 2000);
+	
+}
+void MainWindow::saveAs()
+{
+	if (activeMdiChild() && activeMdiChild()->saveAs())
+	statusBar()->showMessage(tr("File saved"), 2000);
+}
+void MainWindow::cut()
+{
+	if (activeMdiChild())
+	activeMdiChild()->cut();
+}
+void MainWindow::copy()
+{
+	if (activeMdiChild())
+	activeMdiChild()->copy();
+}
+void MainWindow::paste()
+{
+	if (activeMdiChild())
+	activeMdiChild()->paste();
+}
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-7.780</h2>"
-		"<p>Copyright &copy; 2007-2009"
+		tr("<h2>segatex-7.791</h2>"
+		"<p>Copyright &copy; 2007-2010"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
 		"<p><b>written with Qt</b>."));
@@ -656,7 +708,47 @@ MdiChild *MainWindow::createMdiChild()
 	getenforce_str = segatex_state->getenforce_segatex();
 	segatex_selinux_policy_root_str = segatex_state->segatex_selinux_policy_root();
 	segatex_security_policyvers_int = segatex_state->segatex_security_policyvers();
-	//segatex_security_policyvers_str = (QString)segatex_security_policyvers_int;
+	segatex_security_policyvers_int_decimal = segatex_security_policyvers_int / 10; 
+	segatex_security_policyvers_int_small = segatex_security_policyvers_int % 10; 
+	if(segatex_security_policyvers_int_decimal == 1)
+		segatex_security_policyvers_str_decimal = "1";
+	if(segatex_security_policyvers_int_decimal == 2)
+		segatex_security_policyvers_str_decimal = "2";
+	if(segatex_security_policyvers_int_decimal == 3)
+		segatex_security_policyvers_str_decimal = "3";
+	if(segatex_security_policyvers_int_decimal == 4)
+		segatex_security_policyvers_str_decimal = "4";
+	if(segatex_security_policyvers_int_decimal == 5)
+		segatex_security_policyvers_str_decimal = "5";
+	if(segatex_security_policyvers_int_decimal == 6)
+		segatex_security_policyvers_str_decimal = "6";
+	if(segatex_security_policyvers_int_decimal == 7)
+		segatex_security_policyvers_str_decimal = "7";
+	if(segatex_security_policyvers_int_decimal == 8)
+		segatex_security_policyvers_str_decimal = "8";
+	if(segatex_security_policyvers_int_decimal == 9)
+		segatex_security_policyvers_str_decimal = "9";
+	if(segatex_security_policyvers_int_small == 0)
+		segatex_security_policyvers_str_small = "0";
+	if(segatex_security_policyvers_int_small == 1)
+		segatex_security_policyvers_str_small = "1";
+	if(segatex_security_policyvers_int_small == 2)
+		segatex_security_policyvers_str_small = "2";
+	if(segatex_security_policyvers_int_small == 3)
+		segatex_security_policyvers_str_small = "3";
+	if(segatex_security_policyvers_int_small == 4)
+		segatex_security_policyvers_str_small = "4";
+	if(segatex_security_policyvers_int_small == 5)
+		segatex_security_policyvers_str_small = "5";
+	if(segatex_security_policyvers_int_small == 6)
+		segatex_security_policyvers_str_small = "6";
+	if(segatex_security_policyvers_int_small == 7)
+		segatex_security_policyvers_str_small = "7";
+	if(segatex_security_policyvers_int_small == 8)
+		segatex_security_policyvers_str_small = "8";
+	if(segatex_security_policyvers_int_small == 9)
+		segatex_security_policyvers_str_small = "9";
+	segatex_security_policyvers_str = segatex_security_policyvers_str_decimal + segatex_security_policyvers_str_small;
 	if(enabled_or_not_str == "disabled")
 	{
 		selinux_policy = "SELinux is fully " + enabled_or_not_str + ".";
@@ -664,9 +756,10 @@ MdiChild *MainWindow::createMdiChild()
 	}
 	else
 	{
-		selinux_policy = "SELinux is " + enabled_or_not_str + " and policy " + selinux_policy + " " + getenforce_str + " is in use."
-		//+ " Policy root is " + segatex_selinux_policy_root_str + " and version is " + segatex_security_policyvers_str + ".";
-		+ " Policy root is " + segatex_selinux_policy_root_str;
+		//selinux_policy = "SELinux is " + enabled_or_not_str + " and policy " + selinux_policy + " " + getenforce_str + " is in use."
+		selinux_policy = "SELinux is " + enabled_or_not_str + " and "+ selinux_policy + " policy in " + getenforce_str + " mode. "
+		+ " Policy root is " + segatex_selinux_policy_root_str + " and version is " + segatex_security_policyvers_str + ".";
+		//+ " Policy root is " + segatex_selinux_policy_root_str;
 		/*
 		if(getenforce_str == "enforcing")
 			segatexStateLabel->setPaletteBackgroundColor(QColor(155, 155, 255));
@@ -900,6 +993,15 @@ void MainWindow::seinfo()
 	seinfo_o->raise();
 	seinfo_o->setActiveWindow();
 }
+void MainWindow::sesearch()
+{
+	if(!sesearch_o) {
+		sesearch_o = new Sesearch(this);
+	}
+	sesearch_o->show();
+	sesearch_o->raise();
+	sesearch_o->setActiveWindow();
+}
 void MainWindow::autorelabel_process()
 {
 	if(!autorelabel_process_o) {
@@ -1002,6 +1104,51 @@ void MainWindow::segatex_getseuserbyname()
 	segatex_getseuserbyname_o->raise();
 	segatex_getseuserbyname_o->setActiveWindow();
 }
+void MainWindow::segatex_getorderedcontextlist()
+{
+	if(!segatex_getorderedcontextlist_o) {
+		segatex_getorderedcontextlist_o = new SegatexGetorderedcontextlist(this);
+	}
+	segatex_getorderedcontextlist_o->show();
+	segatex_getorderedcontextlist_o->raise();
+	segatex_getorderedcontextlist_o->setActiveWindow();
+}
+void MainWindow::segatex_classaccessvector()
+{
+	if(!segatex_classaccessvector_o) {
+		segatex_classaccessvector_o = new SegatexClassaccessvector(this);
+	}
+	segatex_classaccessvector_o->show();
+	segatex_classaccessvector_o->raise();
+	segatex_classaccessvector_o->setActiveWindow();
+}
+void MainWindow::segatex_booleannames()
+{
+	if(!segatex_booleannames_o) {
+		segatex_booleannames_o = new SegatexBooleannames(this);
+	}
+	segatex_booleannames_o->show();
+	segatex_booleannames_o->raise();
+	segatex_booleannames_o->setActiveWindow();
+}
+void MainWindow::segatex_getpidcon()
+{
+	if(!segatex_getpidcon_o) {
+		segatex_getpidcon_o = new SegatexGetpidcon(this);
+	}
+	segatex_getpidcon_o->show();
+	segatex_getpidcon_o->raise();
+	segatex_getpidcon_o->setActiveWindow();
+}
+void MainWindow::segatex_selinuxpath()
+{
+	if(!segatex_selinuxpath_o) {
+		segatex_selinuxpath_o = new SegatexSelinuxpath(this);
+	}
+	segatex_selinuxpath_o->show();
+	segatex_selinuxpath_o->raise();
+	segatex_selinuxpath_o->setActiveWindow();
+}
 void MainWindow::howtouse()
 {
 	QMessageBox::about(this, tr("How to use"),
@@ -1039,7 +1186,7 @@ void MainWindow::enforcing()
 		connect(segatex_apply, SIGNAL(permissiveOn()), this, SLOT(updateSegatexStateIndicator()));
 		connect(segatex_apply, SIGNAL(enforcingOn()), this, SLOT(updateSegatexStateIndicator()));
 //end for test
-		connect(segatex_apply, SIGNAL(disabledOn()), segatex_apply, SLOT(setenforce_disabled())); 
+		//connect(segatex_apply, SIGNAL(disabledOn()), segatex_apply, SLOT(setenforce_disabled())); 
 		connect(previousAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 	}
 	segatex_apply->show();
