@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <fstream>
+#include <QMessageBox>
 
 #include "policygeneration.h"
 #include "policygeneration_process.h"
@@ -84,7 +85,7 @@ Policygeneration::Policygeneration(QWidget *parent, const char *name): QDialog(p
 	closeButton->setDefault(true);
 
 	//set textEdit smanage such and such -l
-	policygeneration_base_process();
+	policygeneration_base_process(semanageEditLineEdit_str);
 
 	mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
@@ -182,7 +183,9 @@ void Policygeneration::policygeneration_button_clicked_process(QString semanageE
         connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
         process->start();
 
-	policygeneration_base_process();
+	policygeneration_base_process(semanageEditLineEdit_str);
+        QMessageBox::information(0, tr("Wrote module files !"),
+                tr("Wrote " + semanageEditLineEdit_str + ".te, " + semanageEditLineEdit_str + ".fc, " + semanageEditLineEdit_str + ".if in /usr/share/segatex"));
 }
 void Policygeneration::processExited()
 {
@@ -191,7 +194,7 @@ void Policygeneration::processExited()
         this->setEnabled(true);
 }
 
-void Policygeneration::policygeneration_base_process()
+void Policygeneration::policygeneration_base_process(QString semanageEditLineEdit_str)
 {
         #define PWD_BUF 8600
         const char* semanage_login_list_file="/usr/share/segatex/semanage/1_policy_module";
@@ -215,8 +218,10 @@ void Policygeneration::policygeneration_base_process()
 			}
 			pclose(read_fp);
                 }
-        }
+       }
 	os.close();
+	//QMessageBox::warning(0, tr("Wrote module files !"),
+	//	tr("Wrote" + semanageEditLineEdit_str + ".te" + semanageEditLineEdit_str + ".fc" + semanageEditLineEdit_str + ".if in /usr/share/segatex"));
 	readFromOutputFile();
 
 }
