@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,14 +39,6 @@ private slots:
 	void close_button_clicked();
 	void yum_install_base_process();
 	void yum_update_base_process();
-/*
-	void yum_install_targeted_process(int a = 0);
-	void yum_update_targeted_process(int a = 0);
-	void yum_install_strict_process(int a = 0);
-	void yum_update_strict_process(int a = 0);
-	void yum_install_mls_process(int a = 0);
-	void yum_update_mls_process(int a = 0);
-*/
 	void readFromStdout();
 	void readFromStdout1();
 	void updateOutputTextEdit();
