@@ -26,11 +26,14 @@
 #include <qdir.h> 
 #include <qregexp.h> 
 #include <qlabel.h> 
-#include <qtextedit.h>
+#include <q3textedit.h>
+//Added by qt3to4:
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
 
 
 class QLayout;
-class QTextEdit;
+class Q3TextEdit;
 class QLineEdit;
 class QPushButton;
 
@@ -59,16 +62,16 @@ private:
 	QPushButton *deleteButton;
 	QPushButton *modifyButton;
 	QPushButton *closeButton;
-	QTextEdit *textEdit1;
+	Q3TextEdit *textEdit1;
 
-	QVBoxLayout *mainLayout;
-	QVBoxLayout *upperLayout;
-	QVBoxLayout *underLayout;
-	QHBoxLayout *leftLayout;
-	QHBoxLayout *rightLayout;
-	QHBoxLayout *thirdLayout;
-	QVBoxLayout *middleLayout;
-	QHBoxLayout *footLayout;
+	Q3VBoxLayout *mainLayout;
+	Q3VBoxLayout *upperLayout;
+	Q3VBoxLayout *underLayout;
+	Q3HBoxLayout *leftLayout;
+	Q3HBoxLayout *rightLayout;
+	Q3HBoxLayout *thirdLayout;
+	Q3VBoxLayout *middleLayout;
+	Q3HBoxLayout *footLayout;
 
         QDir dir;
         QString path;
